@@ -148,6 +148,19 @@ typedef enum {
 	G_WEBENGINE_HISTORY_PURGE
 } GWebEngineHistoryEvent;
 
+/** GWebEngineSearchResult.
+  * Enumerates search results.
+  */
+typedef enum
+{
+    /**< Unsuccesfull find */
+    G_WEBENGINE_SEARCH_NOTFOUND,
+    /**< Succesfull find */
+    G_WEBENGINE_SEARCH_FOUND,
+    /**< Successful find, but wrapped around */
+    G_WEBENGINE_SEARCH_WRAPPED
+} GWebEngineSearchResult;
+
 #define G_TYPE_WEB_ENGINE             (g_web_engine_get_type ())
 #define G_WEB_ENGINE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_TYPE_WEB_ENGINE, GWebEngine))
 #define G_WEB_ENGINE_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST ((vtable), G_TYPE_WEB_ENGINE, GWebEngineIface))
@@ -210,6 +223,7 @@ struct _GWebEngineIface {
 	void (*set_language_encoding) (GWebEngine *self, GWebEngineEncoding encoding);
 	void (*set_frame_encoding) (GWebEngine *self, GWebEngineEncoding encoding);
 	gboolean (*find_text) (GWebEngine *self, const gchar *string, gboolean reverse, gboolean whole_word, gboolean case_sensitive, gboolean restart);
+	GWebEngineSearchResult (*type_find_text) (GWebEngine *self, const gchar *string, gboolean reverse, gboolean case_sensitive, gboolean restart);
 	void (*authenticate) (GWebEngine *self, gboolean ok, const gchar *username, const gchar *password);
 	GWebStatus (*cut) (GWebEngine *self);
 	GWebStatus (*copy) (GWebEngine *self);
@@ -228,7 +242,7 @@ struct _GWebEngineIface {
 	void (*invoke_selectmatch) (GWebEngine *self);
 	GArray* (*get_server_certificate) (GWebEngine *self, gpointer context);
 	char* (*get_page_verifier_name) (GWebEngine *self);
-	gboolean (*permit_page_unload) (GWebEngine *self, glong time_sec, glong time_usec, glong timeout_usec);
+	gboolean (*permit_page_unload) (GWebEngine *self);
 	gboolean (*is_engine_editable_widget) (GWebEngine *self);
 	gboolean (*get_thumbnail) ( GWebEngine *self, const gchar* thumbnail_filename, gint width, gint height );
 	void (*enable_shistory_thumbnails )(GWebEngine *self, gboolean enable, gint width, gint height );
@@ -536,9 +550,22 @@ void g_web_engine_set_frame_encoding (GWebEngine *self, GWebEngineEncoding encod
   * @param restart If TRUE, search from the beginning of the document. If FALSE,
   * continue search from previous match
   * @return TRUE if can find specified text. FALSE, if can't
+  * 
+  * OBSOLETED! Please use g_web_engine_type_find_text instead of this function.
   */
 gboolean g_web_engine_find_text (GWebEngine *self, const gchar *string, gboolean reverse, gboolean whole_word, gboolean case_sensitive, gboolean restart);
 
+/** Search for text string in current page.
+  * @param self Object pointer
+  * @param string The text to search for
+  * @param reverse If TRUE, search up/left instead of down/right
+  * @param case_sensitive Accept uppercase/lowercase differences as a match.
+  * @param restart If TRUE, search from the beginning of the document. If FALSE,
+  * continue search from previous match or from page focus point.
+  * @return search result.
+  */
+GWebEngineSearchResult g_web_engine_type_find_text (GWebEngine *self, const gchar *string, gboolean reverse, gboolean case_sensitive, gboolean restart);
+
 /** Submit a pending http authentication request.
   * @param self Object pointer
   * @param ok TRUE if ok was clicked, FALSE if cancel
@@ -670,11 +697,7 @@ gchar* g_web_engine_get_page_verifier_name (GWebEngine *self);
   *  
   * @return Returns TRUE if permission to unload given
   */
-gboolean g_web_engine_permit_page_unload (GWebEngine *self,
-                                          glong time_sec,
-                                          glong time_usec,
-                                          glong timeout_usec,
-                                          guint *timeout_id);
+gboolean g_web_engine_permit_page_unload (GWebEngine *self);
 
 
 /** Generates thumbnail from current web page.
